Skip to content

Dataset

Usage

usage: galaxy dataset [-h] [-l] [-n DATASET_NAME] [--dataset-id DATASET_ID] [-i] [--history-id HISTORY_ID]

UseGalaxy dataset utility.

options:
  -h, --help            show this help message and exit
  -l, --list            List user datasets (default: True)
  -n, --dataset-name DATASET_NAME
                        Dataset name to filter on (default: None)
  --dataset-id, --check-dataset-id DATASET_ID
                        Dataset id to check existence of (default: None)
  -i, --ignore-case     Search for datasets ignoring case (default: False)
  --history-id HISTORY_ID
                        Restrict datasets to a specific history id (default: None)

List datasets

By default, its lists all datasets

galaxy dataset
or using the --list argument:
galaxy dataset --list

Search for an dataset by name

galaxy dataset --dataset-name pasted 
will return all the histories that matches pasted (case sensitive)

┏━━━━━━━━━━━━┳━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━┳━━━━━━━━━━━━┓
┃ dataset id ┃ dataset name ┃ last updated ┃ history id ┃
┡━━━━━━━━━━━━╇━━━━━━━━━━━━━━╇━━━━━━━━━━━━━━╇━━━━━━━━━━━━┩
└────────────┴──────────────┴──────────────┴────────────┘

Search case-insensitively

And you can search case-insensitively

galaxy dataset --dataset-name pasted -i
will return all the histories that matches unn ignoring case

┏━━━━━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━━━━━┓
┃ dataset id       ┃ dataset name ┃ last updated        ┃ history id       ┃
┡━━━━━━━━━━━━━━━━━━╇━━━━━━━━━━━━━━╇━━━━━━━━━━━━━━━━━━━━━╇━━━━━━━━━━━━━━━━━━┩
│ 74df81c5c85d8564 │ Pasted Entry │ 2026-07-23 02:15:41 │ 697304b47bf86889 │
│ f962859c9afb4a74 │ Pasted Entry │ 2026-07-17 01:59:32 │ 697304b47bf86889 │
│ 5f83dfbc1bd20549 │ Pasted Entry │ 2025-09-26 16:18:59 │ bc0a36ece81c9189 │
└──────────────────┴──────────────┴─────────────────────┴──────────────────┘

Check existence

Check that a dataset exists

galaxy dataset --check <id>
or
galaxy dataset --dataset-id <id>

When the dataset exists this will return:

galaxy dataset --check f962859c9afb4a74

Dataset with id f962859c9afb4a74 exists

and when it does not:

galaxy dataset --check A

Dataset with id A does not exist

Restrict datasets to a given history

Show the datasets from an history

galaxy dataset --history-id 697304b47bf86889

┏━━━━━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━━━━━━━━┳━━━━━━━━━━━━━━━━━━┓
┃ dataset id       ┃ dataset name ┃ last updated        ┃ history id       ┃
┡━━━━━━━━━━━━━━━━━━╇━━━━━━━━━━━━━━╇━━━━━━━━━━━━━━━━━━━━━╇━━━━━━━━━━━━━━━━━━┩
│ 74df81c5c85d8564 │ Pasted Entry │ 2026-07-23 02:15:41 │ 697304b47bf86889 │
│ f962859c9afb4a74 │ Pasted Entry │ 2026-07-17 01:59:32 │ 697304b47bf86889 │
└──────────────────┴──────────────┴─────────────────────┴──────────────────┘